@@ -19,6 +19,7 @@ from symupy.components import Vehicle, VehicleList
 # CLASS AND DEFINITIONS
 # ============================================================================
 
+
 class SimulatorRequest:
     def __init__(self):
         self._str_response = ""
@@ -29,7 +30,9 @@ class SimulatorRequest:
 
     def __str__(self):
         return (
-            "Sim Time: {}, VehInNetwork: {}".format(self.current_time, self.current_nbveh)
+            "Sim Time: {}, VehInNetwork: {}".format(
+                self.current_time, self.current_nbveh
+            )
             if self.data_query
             else "Simulation has not started"
         )
@@ -102,7 +105,11 @@ class SimulatorRequest:
         :rtype: dict
         """
         vehids = set((vehid, *args)) if args else set(vehid)
-        data_vehs = [(veh.get("@id"), veh.get(dataval)) for veh in self.get_vehicle_data() if veh.get("@id") in vehids]
+        data_vehs = [
+            (veh.get("@id"), veh.get(dataval))
+            for veh in self.get_vehicle_data()
+            if veh.get("@id") in vehids
+        ]
         return dict(data_vehs)
 
     def is_vehicle_in_network(self, vehid: str, *args) -> bool:
@@ -131,7 +138,9 @@ class SimulatorRequest:
         :rtype: tuple
         """
         return tuple(
-            veh.get("@id") for veh in self.get_vehicle_data() if veh.get("@tron") == link and veh.get("@voie") == lane
+            veh.get("@id")
+            for veh in self.get_vehicle_data()
+            if veh.get("@tron") == link and veh.get("@voie") == lane
         )
 
     def is_vehicle_in_link(self, veh: str, link: str) -> bool:
@@ -163,7 +172,11 @@ class SimulatorRequest:
 
         neighpos = self.query_vehicle_position(*neigh)
 
-        return tuple(nbh for nbh, npos in zip(neigh, neighpos) if float(npos) > float(vehpos))
+        return tuple(
+            nbh
+            for nbh, npos in zip(neigh, neighpos)
+            if float(npos) > float(vehpos)
+        )
 
     def vehicle_upstream_of(self, vehid: str) -> tuple:
         """Get ids of vehicles upstream to vehid
@@ -181,7 +194,11 @@ class SimulatorRequest:
 
         neighpos = self.query_vehicle_position(*neigh)
 
-        return tuple(nbh for nbh, npos in zip(neigh, neighpos) if float(npos) < float(vehpos))
+        return tuple(
+            nbh
+            for nbh, npos in zip(neigh, neighpos)
+            if float(npos) < float(vehpos)
+        )
 
     def create_vehicle_list(self):
         """Initialize 
@@ -204,7 +221,7 @@ class SimulatorRequest:
     @property
     def data_query(self):
         try:
-            return parse(self._str_response)
+            return parse(self._str_response.value)
         except ExpatError:
             return {}
 
